@@ -12,4 +12,4 @@ from .utils.local_store import iSqlConfig
 
 from .cli.run import run
 from .cli.execute import exe
-from .cli.config import config, isqlcfg
\ No newline at end of file
+from .cli.config import config
\ No newline at end of file
