@@ -1,5 +1,4 @@
 import os
-import json
 from pathlib import Path
 
 package_dir = Path(__file__).parent.parent
@@ -8,6 +7,4 @@ tests_dir = base_dir / "tests"
 assets_dir = package_dir / "assets"
 data_dir = assets_dir / "data"
 
-pisql_home = Path(os.path.expanduser("~")) / "pisql"
-
-config = json.loads(open(assets_dir / "config.json", "r").read())
\ No newline at end of file
+pisql_home = Path(os.path.expanduser("~")) / "pisql"
\ No newline at end of file
